# XGMML <img src="https://raw.githubusercontent.com/leovan/xgmml/main/docs/images/logo.png" align="right" alt="logo" height="100" style="border: none; float: right; height: 100px;" />
![Version](https://img.shields.io/pypi/v/xgmml)
![Python Versions](https://img.shields.io/pypi/pyversions/xgmml)
![License](https://img.shields.io/pypi/l/xgmml)
![Downloads](https://img.shields.io/pypi/dm/xgmml)

---

🇺🇸 [README](README.md) | 🇨🇳 [中文说明](README.zh.md)

## Introduction

**XGMML** is a Python library for parsing and generating XGMML files. It provides a simple and intuitive interface for working with XGMML file, making it easy to read and write XGMML file.

It supports Python 3.10+ and following libraries:

- [NetworkX](https://networkx.org/)
- [igraph](https://igraph.org/)

**XGMML** format keeps graph style which can be imported into [Cytoscape](https://cytoscape.org/) to visualize.

## Usage

Install **XGMML** via pip:

```
pip install xgmml
```

For detailed usage, please refer to the document: <https://xgmml.leovan.tech>.

## License

The MIT License (MIT)

Copyright &copy; 2025，<a href="https://leovan.me" target="_blank">范叶亮 | Leo Van</a>
